@@ -1,11 +1,11 @@
 bmgraph <-
 function (net, layout = c("bip", "bip3", "bip3e", "bip4", "force", 
-    "rand", "circ", "stress", "CA"), outline, coord, tcex, alpha = c(1, 
-    1, 1), showLbs, showAtts, att = NULL, lbat = "1", main = NULL, 
-    cex.main, bg, mar, directed, weighted, collRecip, cex, pos, 
-    lwd, lty, ecol, vcol, vcol0, asp, seed = NULL, maxiter = 100, 
-    bwd, clu, pch, tcol, rot, mirrorX, mirrorY, col, hds, vedist, 
-    jitter, ...) 
+    "rand", "circ", "stress", "CA", "circ2"), outline, coord, 
+    tcex, alpha = c(1, 1, 1), showLbs, showAtts, att = NULL, 
+    lbat = "1", main = NULL, cex.main, bg, mar, directed, weighted, 
+    collRecip, cex, pos, lwd, lty, ecol, vcol, vcol0, asp, seed = NULL, 
+    maxiter = 100, bwd, clu, pch, tcol, rot, mirrorX, mirrorY, 
+    col, hds, vedist, jitter, ...) 
 {
     ifelse(is.data.frame(net) == TRUE, net <- as.matrix(net), 
         NA)
@@ -190,6 +190,25 @@ function (net, layout = c("bip", "bip3", "bip3e", "bip4", "force",
         NA)
     ifelse(missing(cex.main) == TRUE, cex.main <- graphics::par()$cex.main, 
         NA)
+    if (!(missing(hds))) {
+        if (isTRUE(hds > 1L) == TRUE) {
+            hds <- (hds/1.5)
+        }
+        else if (isTRUE(hds < 1L) == TRUE) {
+            hds <- (hds/(hds + 0.15))
+        }
+        else if (isTRUE(hds == 0L) == TRUE) {
+            hds <- 0.01
+        }
+        else {
+            NA
+        }
+    }
+    else {
+        hds <- 1L
+    }
+    ifelse(missing(vedist) == TRUE, vedist <- 0, NA)
+    ifelse(isTRUE(vedist > 1L) == TRUE, vedist <- 1L, NA)
     ifelse(missing(rot) == TRUE, NA, rot <- rot * -1)
     if (isTRUE(directed == FALSE) == TRUE) {
         if (isTRUE(z == 1L) == TRUE) {
@@ -464,17 +483,18 @@ function (net, layout = c("bip", "bip3", "bip3e", "bip4", "force",
             crd[, 2] <- crd[, 2] * cos(pi) - crd[, 1] * sin(pi)
             rownames(crd) <- lbs
         }, bip4 = {
-            qd <- n/(n + 6)
-            act1 <- nrm(rng(ceiling(nn/2)) + 1L)
+            qdn <- nn/(nn + 3)
+            qdm <- mm/(mm + 3)
+            act1 <- nrm(rng(ceiling(nn/2)))
             act2 <- nrm(rng(floor(nn/2)))
-            evt1 <- nrm(rng(ceiling(mm/2)) - 1L)
+            evt1 <- nrm(rng(ceiling(mm/2)))
             evt2 <- nrm(rng(floor(mm/2)))
-            Act2 <- cbind((act2 * qd) + ((0.05/qd)), rep(0, floor(nn/2)))
-            Evt2 <- cbind((evt2 * qd) + (0.95 - qd), rep(1, floor(mm/2)))
-            Act1 <- cbind(rep(0, ceiling(nn/2)), (act1 * 0.85) + 
-                0.075)
-            Evt1 <- cbind(rep(1, ceiling(mm/2)), (evt1 * 0.85) + 
-                0.075)
+            Act2 <- cbind((act2 * qdn) + (0.1/qdn), rep(0, floor(nn/2)))
+            Evt2 <- cbind((evt2 * qdm) + (0.1/qdm), rep(1, floor(mm/2)))
+            Act1 <- cbind(rep(0, ceiling(nn/2)), (act1 * qdn) + 
+                (0.1/qdn))
+            Evt1 <- cbind(rep(1, ceiling(mm/2)), (evt1 * qdm) + 
+                (0.1/qdm))
             crd <- as.data.frame(rbind(Act1, Act2, Evt1, Evt2))
             crd[which(is.na(crd))] <- 0.5
             crd[, 2] <- crd[, 2] * cos(pi) - crd[, 1] * sin(pi)
@@ -505,6 +525,23 @@ function (net, layout = c("bip", "bip3", "bip3e", "bip4", "force",
             crd[which(crd[, 2] == -Inf), 2] <- max(crd[, 2])
             ifelse(missing(jitter) == FALSE, crd <- jitter(crd, 
                 amount = jitter), NA)
+        }, circ2 = {
+            act <- seq(1.25, pi * 1.2, len = nn)
+            evt <- seq(min(act), max(act), len = mm)
+            act1 <- rbind(cos(act), sin(act))
+            evt1 <- rbind(cos(evt), sin(evt))
+            evt1[1, ] <- evt1[1, ] * cos(pi) - evt1[2, ] * sin(pi)
+            evt1[2, ] <- evt1[2, ] * cos(pi) - evt1[1, ] * sin(pi)
+            crd <- as.data.frame(t(cbind(act1, evt1)))
+            crd[which(is.na(crd))] <- 0.5
+            rt <- 10
+            crd[, 1] <- (crd[, 1] * cos(rt * (pi/180L)) - crd[, 
+                2] * sin(rt * (pi/180L)))/0.4
+            crd[, 2] <- (crd[, 2] * cos(rt * (pi/180L)) + crd[, 
+                1] * sin(rt * (pi/180L)))/1
+            crd[, 1:2] <- crd[, 1:2] - min(crd[, 1:2])
+            ifelse(isTRUE(flgcx == TRUE) == TRUE, fds <- fds - 
+                50L, NA)
         })
     }
     if (missing(rot) == FALSE) {
@@ -548,6 +585,7 @@ function (net, layout = c("bip", "bip3", "bip3e", "bip4", "force",
         min(crd[, 2]))/(max(crd[, 2]) - min(crd[, 2]))) * (1L/rat), 
         crd[, 2] <- ((crd[, 2] - min(crd[, 2]))/(max(crd[, 2]) - 
             min(crd[, 2]))) * (rat))
+    fds <- fds + (vedist * -10)
     if (isTRUE(flgcrd == TRUE) == TRUE && isTRUE(ncol(crd) > 
         2) == TRUE) {
         lbgml <- tolower(as.vector(crd[, 3]))
@@ -672,7 +710,6 @@ function (net, layout = c("bip", "bip3", "bip3e", "bip4", "force",
         else {
             NA
         }
-        fds <- fds + (r * 2)
     }
     opm <- graphics::par()$mar
     ifelse(all(mar == c(5.1, 4.1, 4.1, 2.1)) == TRUE, mar <- rep(0, 
@@ -855,16 +892,19 @@ function (net, layout = c("bip", "bip3", "bip3e", "bip4", "force",
                 else {
                   lwd <- rep(lwd[1], rr)
                 }
+                flgcr <- FALSE
                 if (isTRUE(z == 1L) == TRUE) {
                   mbnd(pars, rr, bds[[k]], vlt, cx, lwd, vecol, 
-                    directed, asp, bwd, alfa, fds, flgcx, weighted)
+                    directed, bwd, alfa, fds, flgcx, weighted, 
+                    flgcr, hds, n)
                 }
                 else {
                   ifelse(isTRUE(length(lty) == 1L) == TRUE, mbnd(pars, 
                     rr, bds[[k]], vlt1, cx, lwd, vecol[vltc], 
-                    directed, asp, bwd, alfa, fds, flgcx, weighted), 
-                    mbnd(pars, rr, bds[[k]], vlt, cx, lwd, vecol[vltc], 
-                      directed, asp, bwd, alfa, fds, flgcx, weighted))
+                    directed, bwd, alfa, fds, flgcx, weighted, 
+                    flgcr, hds, n), mbnd(pars, rr, bds[[k]], 
+                    vlt, cx, lwd, vecol[vltc], directed, bwd, 
+                    alfa, fds, flgcx, weighted, flgcr, hds, n))
                 }
             }
             else {
@@ -897,36 +937,37 @@ function (net, layout = c("bip", "bip3", "bip3e", "bip4", "force",
             ifelse(isTRUE(max(cex) < 2) == TRUE, tcex <- cex * 
                 0.66, tcex <- cex * 0.33)
         }
+        ndss <- nds
         if (match.arg(layout) == "bip3") {
             if (isTRUE(pos[1] == 0) == TRUE) {
-                graphics::text(nds[seq_len(length(act1)), ], 
+                graphics::text(ndss[seq_len(length(act1)), ], 
                   labels = lbs[seq_len(length(act1))], cex = tcex, 
                   adj = 0.5, col = tcol[1])
             }
             else {
-                graphics::text(nds[seq_len(length(act1)), ], 
+                graphics::text(ndss[seq_len(length(act1)), ], 
                   lbs[seq_len(length(act1))], cex = tcex, pos = pos[1], 
                   col = tcol[1], offset = (cex/4L), adj = c(0.5, 
                     1))
             }
             if (isTRUE(pos[2] == 0) == TRUE) {
-                graphics::text(nds[(nn + 1L):dim(bmnet)[1], ], 
-                  labels = lbs[(nn + 1L):dim(bmnet)[1]], cex = tcex, 
+                graphics::text(ndss[(nn + 1L):dim(bmnet)[1], 
+                  ], labels = lbs[(nn + 1L):dim(bmnet)[1]], cex = tcex, 
                   adj = 0.5, col = tcol[2])
             }
             else {
-                graphics::text(nds[(nn + 1L):dim(bmnet)[1], ], 
-                  lbs[(nn + 1L):dim(bmnet)[1]], cex = tcex, pos = pos[2], 
-                  col = tcol[2], offset = (cex/4L), adj = c(0.5, 
-                    1))
+                graphics::text(ndss[(nn + 1L):dim(bmnet)[1], 
+                  ], lbs[(nn + 1L):dim(bmnet)[1]], cex = tcex, 
+                  pos = pos[2], col = tcol[2], offset = (cex/4L), 
+                  adj = c(0.5, 1))
             }
             if (isTRUE(pos[3] == 0) == TRUE) {
-                graphics::text(nds[(length(act1) + 1):nn, ], 
+                graphics::text(ndss[(length(act1) + 1):nn, ], 
                   labels = lbs[(length(act1) + 1):nn], cex = tcex, 
                   adj = 0.5, col = tcol[1])
             }
             else {
-                graphics::text(nds[(length(act1) + 1):nn, ], 
+                graphics::text(ndss[(length(act1) + 1):nn, ], 
                   lbs[(length(act1) + 1):nn], cex = tcex, pos = pos[3], 
                   col = tcol[1], offset = (cex/4L), adj = c(0.5, 
                     1))
@@ -934,32 +975,34 @@ function (net, layout = c("bip", "bip3", "bip3e", "bip4", "force",
         }
         else if (match.arg(layout) == "bip3e") {
             if (isTRUE(pos[2] == 0) == TRUE) {
-                graphics::text(nds[seq_len(length(act)), ], labels = lbs[seq_len(length(act))], 
-                  cex = tcex, adj = 0.5, col = tcol[2])
+                graphics::text(ndss[seq_len(length(act)), ], 
+                  labels = lbs[seq_len(length(act))], cex = tcex, 
+                  adj = 0.5, col = tcol[2])
             }
             else {
-                graphics::text(nds[seq_len(length(act)), ], lbs[seq_len(length(act))], 
-                  cex = tcex, pos = pos[2], col = tcol[2], offset = (cex/4L), 
-                  adj = c(0.5, 1))
+                graphics::text(ndss[seq_len(length(act)), ], 
+                  lbs[seq_len(length(act))], cex = tcex, pos = pos[2], 
+                  col = tcol[2], offset = (cex/4L), adj = c(0.5, 
+                    1))
             }
             if (isTRUE(pos[1] == 0) == TRUE) {
-                graphics::text(nds[(nn + 1L):(nn + length(evt1)), 
+                graphics::text(ndss[(nn + 1L):(nn + length(evt1)), 
                   ], labels = lbs[(nn + 1L):(nn + length(evt1))], 
                   cex = tcex, adj = 0.5, col = tcol[1])
             }
             else {
-                graphics::text(nds[(nn + 1L):(nn + length(evt1)), 
+                graphics::text(ndss[(nn + 1L):(nn + length(evt1)), 
                   ], lbs[(nn + 1L):(nn + length(evt1))], cex = tcex, 
                   pos = pos[1], col = tcol[1], offset = (cex/4L), 
                   adj = c(0.5, 1))
             }
             if (isTRUE(pos[3] == 0) == TRUE) {
-                graphics::text(nds[(nn + 1 + length(evt1)):dim(bmnet)[1], 
+                graphics::text(ndss[(nn + 1 + length(evt1)):dim(bmnet)[1], 
                   ], labels = lbs[(nn + 1 + length(evt1)):dim(bmnet)[1]], 
                   cex = tcex, adj = 0.5, col = tcol[1])
             }
             else {
-                graphics::text(nds[(nn + 1 + length(evt1)):dim(bmnet)[1], 
+                graphics::text(ndss[(nn + 1 + length(evt1)):dim(bmnet)[1], 
                   ], lbs[(nn + 1 + length(evt1)):dim(bmnet)[1]], 
                   cex = tcex, pos = pos[3], col = tcol[1], offset = (cex/4L), 
                   adj = c(0.5, 1))
@@ -967,37 +1010,37 @@ function (net, layout = c("bip", "bip3", "bip3e", "bip4", "force",
         }
         else if (match.arg(layout) == "bip4") {
             if (isTRUE(pos[1] == 0) == TRUE) {
-                graphics::text(nds[seq_len(length(act1)), ], 
+                graphics::text(ndss[seq_len(length(act1)), ], 
                   labels = lbs[seq_len(length(act1))], cex = tcex, 
                   adj = 0.5, col = tcol[1])
-                graphics::text(nds[(length(act1) + 1):nn, ], 
+                graphics::text(ndss[(length(act1) + 1):nn, ], 
                   labels = lbs[(length(act1) + 1):nn], cex = tcex, 
                   adj = 0.5, col = tcol[1])
             }
             else {
-                graphics::text(nds[seq_len(length(act1)), ], 
+                graphics::text(ndss[seq_len(length(act1)), ], 
                   lbs[seq_len(length(act1))], cex = tcex, pos = pos[1], 
                   col = tcol[1], offset = (cex/4L), adj = c(0.5, 
                     1))
-                graphics::text(nds[(length(act1) + 1):nn, ], 
+                graphics::text(ndss[(length(act1) + 1):nn, ], 
                   labels = lbs[(length(act1) + 1):nn], cex = tcex, 
                   pos = pos[3], col = tcol[1], offset = (cex/4L), 
                   adj = c(0.5, 1))
             }
             if (isTRUE(pos[2] == 0) == TRUE) {
-                graphics::text(nds[(nn + 1L):(nn + length(evt1)), 
+                graphics::text(ndss[(nn + 1L):(nn + length(evt1)), 
                   ], labels = lbs[(nn + 1L):(nn + length(evt1))], 
                   cex = tcex, adj = 0.5, col = tcol[2])
-                graphics::text(nds[(nn + 1 + length(evt1)):dim(bmnet)[1], 
+                graphics::text(ndss[(nn + 1 + length(evt1)):dim(bmnet)[1], 
                   ], labels = lbs[(nn + 1 + length(evt1)):dim(bmnet)[1]], 
                   cex = tcex, adj = 0.5, col = tcol[2])
             }
             else {
-                graphics::text(nds[(nn + 1L):(nn + length(evt1)), 
+                graphics::text(ndss[(nn + 1L):(nn + length(evt1)), 
                   ], labels = lbs[(nn + 1L):(nn + length(evt1))], 
                   cex = tcex, pos = pos[2], col = tcol[2], offset = (cex/4L), 
                   adj = c(0.5, 1))
-                graphics::text(nds[(nn + 1 + length(evt1)):dim(bmnet)[1], 
+                graphics::text(ndss[(nn + 1 + length(evt1)):dim(bmnet)[1], 
                   ], lbs[(nn + 1 + length(evt1)):dim(bmnet)[1]], 
                   cex = tcex, pos = pos[4], col = tcol[2], offset = (cex/4L), 
                   adj = c(0.5, 1))
@@ -1006,21 +1049,21 @@ function (net, layout = c("bip", "bip3", "bip3e", "bip4", "force",
         else {
             if (isTRUE(length(pos) == 2) == TRUE) {
                 if (isTRUE(pos[1] == 0) == TRUE) {
-                  graphics::text(nds[seq_len(nn), ], labels = lbs[seq_len(nn)], 
+                  graphics::text(ndss[seq_len(nn), ], labels = lbs[seq_len(nn)], 
                     cex = tcex, adj = 0.5, col = tcol[1])
                 }
                 else {
-                  graphics::text(nds[seq_len(nn), ], lbs[seq_len(nn)], 
+                  graphics::text(ndss[seq_len(nn), ], lbs[seq_len(nn)], 
                     cex = tcex, pos = pos[1], col = tcol[1], 
                     offset = (cex/4L), adj = c(0.5, 1))
                 }
                 if (isTRUE(pos[2] == 0) == TRUE) {
-                  graphics::text(nds[(nn + 1L):dim(bmnet)[1], 
+                  graphics::text(ndss[(nn + 1L):dim(bmnet)[1], 
                     ], labels = lbs[(nn + 1L):dim(bmnet)[1]], 
                     cex = tcex, adj = 0.5, col = tcol[2])
                 }
                 else {
-                  graphics::text(nds[(nn + 1L):dim(bmnet)[1], 
+                  graphics::text(ndss[(nn + 1L):dim(bmnet)[1], 
                     ], lbs[(nn + 1L):dim(bmnet)[1]], cex = tcex, 
                     pos = pos[2], col = tcol[2], offset = (cex/4L), 
                     adj = c(0.5, 1))
@@ -1028,11 +1071,11 @@ function (net, layout = c("bip", "bip3", "bip3e", "bip4", "force",
             }
             else if (isTRUE(length(pos) == 1) == TRUE) {
                 if (isTRUE(pos == 0) == TRUE) {
-                  graphics::text(nds, labels = lbs, cex = tcex, 
+                  graphics::text(ndss, labels = lbs, cex = tcex, 
                     adj = 0.5, col = tcol[1])
                 }
                 else {
-                  graphics::text(nds, lbs, cex = tcex, pos = pos, 
+                  graphics::text(ndss, lbs, cex = tcex, pos = pos, 
                     col = tcol[1], offset = (cex/4L), adj = c(0.5, 
                       1))
                 }
